import { View, Text } from '@tarojs/components'
import dayjs from 'dayjs'
import { FC, useState } from 'react'
import DropDownItem from '../dropDown-item'
import FilterButton from '../filterButton'
import IconFont from '../iconfont/iconfont'
import TimePicker from '../timePicker'
import styles from './index.module.scss'

type ChangedValue = string | number

interface SelectSaleTypeProps {
  onChange?: (value: ChangedValue) => void
}

const FilterTimeOptions = {
  '0': {
    name: '全部',
    date_min: undefined,
    date_max: undefined,
  },
  '1': {
    name: '今天',
    date_min: `${dayjs(new Date())
      .add(0, 'day')
      .format('YYYY-MM-DD')} 00:00:00`,
    date_max: `${dayjs(new Date())
      .add(1, 'day')
      .format('YYYY-MM-DD')} 00:00:00`,
  },
  '2': {
    name: '昨日',
    date_min: `${dayjs(new Date())
      .add(-1, 'day')
      .format('YYYY-MM-DD')} 00:00:00`,
    date_max: `${dayjs(new Date())
      .add(0, 'day')
      .format('YYYY-MM-DD')} 00:00:00`,
  },
  '3': {
    name: '近7日',
    date_min: `${dayjs(new Date())
      .add(-7, 'day')
      .format('YYYY-MM-DD')} 00:00:00`,
    date_max: `${dayjs(new Date())
      .add(0, 'day')
      .format('YYYY-MM-DD')} 00:00:00`,
  },
  '4': {
    name: '近30日',
    date_min: `${dayjs(new Date())
      .add(-30, 'day')
      .format('YYYY-MM-DD')} 00:00:00`,
    date_max: `${dayjs(new Date())
      .add(0, 'day')
      .format('YYYY-MM-DD')} 00:00:00`,
  },
  '5': {
    name: '近90日',
    date_min: `${dayjs(new Date())
      .add(-90, 'day')
      .format('YYYY-MM-DD')} 00:00:00`,
    date_max: `${dayjs(new Date())
      .add(0, 'day')
      .format('YYYY-MM-DD')} 00:00:00`,
  },
} as const

type Key = keyof typeof FilterTimeOptions
type Value = (typeof FilterTimeOptions)[Key] 

const SelectTimePicker: FC<SelectSaleTypeProps> = props => {
  const { onChange: change } = props
  const [currentValue, setCurrentValue] = useState('0')

  const [currentDate, setCurrentDate] = useState({
    start: new Date(),
    end: new Date(),
  })

  

  const onSelectDate = time => {
    console.log(time)
    change?.(time)
  }

  const handleClick = (key: Key) => {
    setCurrentValue(key)
  }

  return (
    <DropDownItem title='查询日期' direction='down' value={currentValue} activeColor='#337fff'>
      <View className={styles.grid} style={{ paddingBottom: '24rpx' }}>
        {Object.entries(FilterTimeOptions).map(([key, value]) => {
          return (
            <FilterButton isActive={key === currentValue} onClick={() => handleClick(key as Key)}>
              {value.name}
            </FilterButton>
          )
        })}
        <FilterButton customClassName={styles.customFilterTime} isActive={'6' === currentValue} onClick={() => handleClick('6' as Key)}>
          <Text>自定义时间</Text>
          <IconFont name='icon-chakanquanbukehu' color={'6' === currentValue ? '#3983ff' : '#7f7f7f'}></IconFont>
        </FilterButton>
      </View>
      <View style={{ paddingBottom: '24rpx' }}>
        <TimePicker start={currentDate.start} end={currentDate.end} onSelectDate={onSelectDate}></TimePicker>
      </View>
    </DropDownItem>
  )
}
export default SelectTimePicker
