import { View, Text } from '@tarojs/components'
import { FC, useEffect, useState } from 'react'
import styles from './index.module.scss'
import LineBluetooth from '../components/bluetooth/LinkBlueTooth'
import HistoryColor from './components/HistoryColor'
import LabColor from './components/LabColor'
import SelectProduct from '@/components/selectProduct'
import { useBluetooth } from '@/use/contextBlueTooth'
import RecommendColor from './components/RecommendColor'
import { FindColorListApi } from '@/api/index'
import Loading from '@/components/loading'
import Taro from '@tarojs/taro'
import { throttle } from '@/common/util'

const FindColor: FC = () => {
  const { measureAndGetLab, disconnect, connected, deviceLab } = useBluetooth()
  const { state: colorState, fetchData: ApiFindColorList } = FindColorListApi()

  const [list, setList] = useState([])
  const [product, setProduct] = useState<Record<string, any>>({})

  //获取数据
  const getData = async () => {
    setList([])
    await ApiFindColorList({
      product_id: product.id,
      l: labArray[0],
      a: labArray[1],
      b: labArray[2],
    })
    setList(colorState.data.list)
  }

  const [labArray, setlabArray] = useState<Array<any>>([])
  const [labtime, setLabtime] = useState<any>(+new Date())
  //点击获取lab按钮
  const labEven = throttle(async () => {
    if (!connected) {
      Taro.showToast({ title: '请先链接设备', icon: 'none' })
      return
    }
    if (!product) {
      Taro.showToast({ title: '请选择面料', icon: 'none' })
      return
    }
    await measureAndGetLab()
  }, 500)
  const selectInput = (val) => {
    setProduct(val)
    setLabtime('')
    setlabArray([])
    setList([])
  }

  const getColor = (val) => {
    setList([])
    setlabArray(val.lab)
    setLabtime(val.p_time)
    setProduct({
      code: val.code,
      default: val.default,
      id: val.id,
      name: val.name,
    })
    getData()
  }

  const [listLoading, setListLoading] = useState(false)

  useEffect(() => {
    setListLoading(colorState.loading)
  }, [colorState])

  const [showHistory, setShowHistory] = useState(false)

  const ResultContainer = () => {
    if (!listLoading && list?.length > 0) {
      return <RecommendColor customStyle={{ flex: 1 }} list={list} />
    } else if (!listLoading && labArray.length == 0) {
      return <View className={styles.noList}>-请取色-</View>
    } else if (!listLoading && labArray.length > 0 && list?.length == 0) {
      return <View className={styles.noList}>-暂无数据-</View>
    } else if (listLoading) {
      return <Loading />
    }
  }

  //历史取样
  const historyShowEven = () => {
    setShowHistory(true)
  }

  useEffect(() => {
    if (!product) {
      Taro.showToast({ title: '请选择面料', icon: 'none' })
      return
    }
    if (deviceLab) {
      setLabtime(+new Date())
      setlabArray([deviceLab.L, deviceLab.a, deviceLab.b])
      // console.log('state.labArray::',state.labArray)
      localSave()
      getData()
    }
  }, [deviceLab])

  //本地存储取色记录(无差别存储版本)
  const localSave = () => {
    let historyColorList = Taro.getStorageSync('historyColor') || []
    let obj = {
      ...product,
      p_time: labtime,
      lab: labArray,
    }
    historyColorList.unshift(obj)
    if (historyColorList.length > 30) historyColorList.pop()
    Taro.setStorageSync('historyColor', historyColorList)
  }

  return (
    <View className={styles.findColor_main}>
      <View className={styles.findColor_main_search}>
        <LineBluetooth></LineBluetooth>
        <SelectProduct selectColorId={product?.id} noAll={true} onSelect={selectInput} />
      </View>
      <LabColor lab={labArray} time={labtime} onLab={labEven} />
      <View className={styles.findColor_main_title}>
        <View className={styles.RecommendColor_title}>
          <Text>推荐数 ({list?.length})</Text>
          <Text onClick={historyShowEven}>历史取样</Text>
        </View>
      </View>
      <HistoryColor showModal={showHistory} onColor={getColor} />
      {ResultContainer()}
      <View className='common_safe_area_y'></View>
    </View>
  )
}

export default FindColor
