import { Text, View } from '@tarojs/components'
import { FC, memo, useCallback, useContext, useEffect, useMemo, useRef, useState } from 'react'
import styles from './index.module.scss'
import classnames from 'classnames'
import { formatMeterDiv, formatPriceDiv } from '@/common/format'
import Taro, { useDidShow } from '@tarojs/taro'
import LayoutBlock from '@/components/layoutBlock'
import MCheckbox from '@/components/checkbox'
import Tag from '@/components/tag'
import Divider from '@/components/divider'
import ColorKindItem from '../colorKindItem'
import { EnumSaleMode } from '@/common/Enumerate'
import { useNeedMemoCallback } from '@/use/useCommon'
import { selectList } from '../../config'
import { Goods, useShoppingContext } from '../../context'
import IconFont from '@/components/iconfont/iconfont'
import { isEmptyObject } from '@/common/common'

type PropsType = {
  itemData?: ShoppingCartData
}

const DrawerButton = memo<{ isOpen: boolean }>(({ isOpen }) => {
  return (
    <View className={styles.drawerButton}>
      {isOpen ? <IconFont name='icon-shouqi' size={52}></IconFont> : <IconFont name='icon-zhankai' size={52}></IconFont>}
    </View>
  )
})

enum BackEndSaleModeListFieldMap {
  bulk_color_list = 0,
  length_cut_color_list = 1,
  weight_cut_color_list = 2,
}

export default memo<PropsType>(props => {
  const { itemData } = props

  const { setCurrentCheckedSaleMode } = useShoppingContext()

  const [openDetail, setOpenDetail] = useState(false)

  const handleOpenDetail = () => {
    setOpenDetail(isOpen => !isOpen)
    handleClickLayout()
  }

  const [selected, setSelect] = useState<EnumSaleMode>(0)

  const onSelectOrderType = (type: EnumSaleMode) => {
    setSelect(type)
    setCurrentCheckedSaleMode(type)
    // 重置预估金额
    setSelectedAmount(0)
  }

  const saleModeList = useRef({
    bulk_color_list: itemData?.bulk_color_list,
    length_cut_color_list: itemData?.length_cut_color_list,
    weight_cut_color_list: itemData?.weight_cut_color_list,
  })
  saleModeList.current = {
    bulk_color_list: itemData?.bulk_color_list,
    length_cut_color_list: itemData?.length_cut_color_list,
    weight_cut_color_list: itemData?.weight_cut_color_list,
  }

  const { setChangedCheckbox, currentCheckedPurchaserId, setCurrentCheckedPurchaserId, isManageStatus, setSelectedAmount, colorStore, currentCheckedSaleMode } = useShoppingContext()

  const memoList = useMemo(() => {
    const selectedList = itemData?.[BackEndSaleModeListFieldMap[selected]].length !== 0 ? itemData?.[BackEndSaleModeListFieldMap[selected]] : [{}]
    // 给每一个客户都初始化一个 checked 状态
    selectedList.forEach(() => {
      // 初始化选中状态
      setChangedCheckbox({
        purchaserId: itemData?.purchaser_id!,
        checked: false,
      })
    })
    // 向 context 中初始化数据
    return itemData?.[BackEndSaleModeListFieldMap[selected]].length !== 0 ? (
      itemData?.[BackEndSaleModeListFieldMap[selected]].map(item => {
        setChangedCheckbox({
          purchaserId: itemData?.purchaser_id!,
          goodsKind: {
            [item?.id]: {
              id: item?.id,
              estimate_amount: item.estimate_amount,
              checked: false,
              product_code: item.product_code,
              product_color_code: item.product_color_code,
              sale_mode: item.sale_mode,
              count: selected === EnumSaleMode.Bulk ? item.roll : Number(formatMeterDiv(item.length)),
            },
          },
          checked: false,
        })
        return <ColorKindItem purchaserId={itemData.purchaser_id} key={item.id} itemData={item} orderType={selected}></ColorKindItem>
      })
    ) : (
      <View className={styles.noList}>暂无数据</View>
    )
  }, [itemData, selected])

  const handleClickLayout = () => {
    if (currentCheckedPurchaserId === itemData?.purchaser_id) {
      return
    }
    setSelectedAmount(0)
    setCurrentCheckedSaleMode(selected)
    setCurrentCheckedPurchaserId(itemData?.purchaser_id as number)
  }

  const handleChecked = () => {
    // 初始化选中状态
    setChangedCheckbox({
      purchaserId: itemData?.purchaser_id!,
      checked: true,
    })
  }
  const handleUnchecked = () => {
    // 初始化选中状态
    setChangedCheckbox({
      purchaserId: itemData?.purchaser_id!,
      checked: false,
    })
  }
  // 统计已选面料
  const materialChecked = useMemo(() => {
    const targetGoodsKind = colorStore?.[itemData?.purchaser_id!]?.['goodsKind']
    if (!targetGoodsKind || isEmptyObject(targetGoodsKind)) return 0
    return new Set(
      Object.values(targetGoodsKind)?.reduce((prev, item: Goods) => {
        if (item.checked && item.sale_mode === selected) {
          return [...prev, item.product_code]
        }
        return prev
      }, []),
    ).size
  }, [colorStore, currentCheckedPurchaserId, selected, itemData])

  // 统计已选颜色
  const colorChecked = useMemo(() => {
    const targetGoodsKind = colorStore?.[itemData?.purchaser_id!]?.['goodsKind']
    if (!targetGoodsKind || isEmptyObject(targetGoodsKind)) return 0
    return new Set(
      Object.values(targetGoodsKind).reduce((prev, item: Goods) => {
        if (item.checked && item.sale_mode === selected) {
          return [...prev, item.product_color_code]
        }
        return prev
      }, []),
    ).size
  }, [colorStore, currentCheckedPurchaserId, selected, itemData])

  // 统计已选条数 / 米数
  const lengthOrRollChecked = useMemo(() => {
    const targetGoodsKind = colorStore?.[itemData?.purchaser_id!]?.['goodsKind']
    if (!targetGoodsKind || isEmptyObject(targetGoodsKind)) return 0
    return (
      Object.values(targetGoodsKind).reduce((prev, item: Goods) => {
        if (item.checked && item.sale_mode === selected) {
          return prev + item.count
        }
        return prev
      }, 0) || 0
    )
  }, [colorStore, currentCheckedPurchaserId, selected, itemData])

  return (
    <LayoutBlock
      circle
      customClassName={classnames(styles.layout, itemData?.purchaser_id === currentCheckedPurchaserId ? styles.selected : '')}
      onClick={handleClickLayout}>
      <MCheckbox
        hiddenCheckboxIcon={!isManageStatus}
        onSelect={handleChecked}
        onClose={handleUnchecked}
        status={colorStore[itemData?.purchaser_id!]?.checked}
        customClassName={styles['checkbox']}
        customTextClass={styles['checkbox--text']}
        triggerLabel={false}>
        <View className='flex-row justify-between' onClick={handleOpenDetail}>
          <View className={styles.topItem}>
            <View className='flex-row items-center'>
              <View className={styles.topTitle}>{itemData?.purchaser_name}</View>
              <Tag type='info' size='normal' circle customStyle={{ backgroundColor: '#f0f0f0',borderColor: 'transparent' }} plain>
                {itemData?.sale_user_name}
              </Tag>
            </View>
            <View className={styles.summary}>
              <Text>
                已选 {materialChecked} 种面料，{colorChecked} 个颜色，共{' '}
                {selected === EnumSaleMode.Bulk ? `${lengthOrRollChecked} 条` : `${lengthOrRollChecked} 米`}
              </Text>
            </View>
          </View>
          <DrawerButton isOpen={openDetail} />
        </View>
      </MCheckbox>
      {/* 减少节点渲染 */}
      {openDetail && (
        <View className={classnames(styles.detailBox, openDetail ? styles.drawerOpen : styles.drawerClose)}>
          <View className={styles.orderType}>
            <Divider customClassName={styles.line}></Divider>
            <View className={styles.orderTitle}>订单类型</View>
            <View className={styles.orderTypeDetail}>
              <SaleModeButton
                customStyle={{ padding: '0 50rpx' }}
                isActive={selected === EnumSaleMode.Bulk}
                onClick={() => onSelectOrderType(EnumSaleMode.Bulk)}>
                大货
              </SaleModeButton>
              <SaleModeButton
                customStyle={{ padding: '0 50rpx' }}
                isActive={selected === EnumSaleMode.Plate}
                onClick={() => onSelectOrderType(EnumSaleMode.Plate)}>
                剪板
              </SaleModeButton>
              <SaleModeButton
                customStyle={{ padding: '0 50rpx' }}
                isActive={selected === EnumSaleMode.BulkCut}
                onClick={() => onSelectOrderType(EnumSaleMode.BulkCut)}>
                散剪
              </SaleModeButton>
            </View>
          </View>
          <View className={styles.orderColor}>
            <Divider customClassName={styles.line}></Divider>
            <View className={classnames(styles.orderTitle, 'justify-between')}>
              <Text>布料颜色</Text>
              <Tag type='danger' size='normal' circle plain>
                {selectList[selected].title}单位：{selectList[selected].unit}
              </Tag>
            </View>
          </View>
          <View className={styles.orderContainer}>{memoList}</View>
        </View>
      )}
    </LayoutBlock>
  )
}, useNeedMemoCallback())

interface ButtonPropsType {
  isActive: boolean
  onClick?: Function
  children?: React.ReactNode
  customStyle?: React.CSSProperties
}
// 订单类型
const SaleModeButton: FC<ButtonPropsType> = props => {
  const { onClick, children, isActive = false, customStyle } = props
  const handleClick = () => {
    onClick?.()
  }
  return (
    <View className={classnames(styles.saleModeButton, isActive && styles['saleModeButton--active'])} style={customStyle} onClick={handleClick}>
      <View className={classnames(styles['saleModeButton--text'])}>{children}</View>
    </View>
  )
}
